@@ -6,3 +6,6 @@ aclocal \
   && automake --add-missing --foreign --copy \
   && autoconf \
   && ./configure --enable-maintainer-mode $@
+
+# clean up a bit
+rm -rf ./autom4te.cache
