@@ -319,7 +319,7 @@ char *get_default_track_title( int track )
 	static char name_buf[ MAX_FILE_NAME_LENGTH ];
 	char *name_format = config.mp3_file_name_format;
 	char track_no_buf[ 5 ];
-	int read_offset, write_offset, return_val;
+	int read_offset, write_offset;
 
 	read_offset = -1;
 	write_offset = 0;
@@ -407,9 +407,9 @@ int high_ascii_to_low_ascii ( unsigned char *p )
 		return 1;
 }
 
-void remove_non_unix_chars( unsigned char *src )
+void remove_non_unix_chars( char *src )
 {
-	unsigned char *p = src, *w = p;
+	unsigned char *p = (unsigned char *)src, *w = p;
 
 	for (; *p != 0; p++ ) {
 	
@@ -701,11 +701,9 @@ long check_free_space(char* dir)
 	FILE *file;
 	long len;
 	char cmd[MAX_FILE_NAME_LENGTH];
-	char buffer[MAX_FILE_NAME_LENGTH];
 
 	snprintf(cmd, MAX_FILE_NAME_LENGTH - 1, "df -P '%s' 2>/dev/null | awk '{print $4}' | tail -1", dir);
 	file = popen(cmd, "r");
-	//fscanf(file, "%s\n", &buffer); /* read the Available title */
 	fscanf(file, "%ld", &len); /* now read the length */
 	pclose(file);
 	return len;
@@ -784,7 +782,7 @@ int create_filenames_from_format(_main_data *main_data)
 {
 	int i;
 	int rc2;
-	static char *df;
+	static unsigned char *df;
 
 	i = strlen(config.wav_path) - 1;
 	if (i >= 0 && config.wav_path[i] == '/')
@@ -846,7 +844,7 @@ int create_file_names_for_track(_main_data *main_data, int track, char **wfp, ch
 {
 	static char *buffer;
 	int rc;
-	
+	char *conv_str = NULL;
 
 	rc = parse_rx_format_string(&buffer,
 		config.cddb_config.format_string, track, 
@@ -860,16 +858,21 @@ int create_file_names_for_track(_main_data *main_data, int track, char **wfp, ch
 	if (buffer[0] == 0)
 		strcpy( buffer, main_data->track[ track ].title );
 
-	remove_non_unix_chars( buffer );
-	convert_slashes(buffer, '-');	 
+	conv_str = g_locale_from_utf8(buffer, -1, NULL, NULL, NULL);
+
+	remove_non_unix_chars( conv_str );
+	convert_slashes(conv_str, '-');	 
 	if ( config.cddb_config.convert_spaces == TRUE ) {
-		convert_spaces( buffer, '_' );
+		convert_spaces( conv_str, '_' );
 	}
 
 	if (wfp)
-		mk_strcat(wfp, wd, buffer, wfext, NULL);
+		mk_strcat(wfp, wd, conv_str, wfext, NULL);
 	if (efp)
-		mk_strcat(efp, ed, buffer, ecfext, NULL);
+		mk_strcat(efp, ed, conv_str, ecfext, NULL);
+
+	g_free(conv_str);	
+
 	return 1;
 }
 
@@ -902,7 +905,7 @@ void put_track_title(char *src, _main_data *main_data, int tno)
 		++sp;
 
 	/* Split off track artist if specified */
-	if (cp = rindex(sp, '/')) {
+	if ((cp = rindex(sp, '/'))) {
 		for (ep = cp - 1; ep > sp && isspace(*ep); --ep)
 			;
 		c = *(++ep);
@@ -980,12 +983,12 @@ void mk_strcat(char **ptr, ...)
 	int tlen = 0;
 
 	va_start(ap, ptr);
-	while (cp = va_arg(ap, char *))
+	while ((cp = va_arg(ap, char *)))
 		tlen += strlen(cp);
 	va_end(ap);
 	mk_buf(ptr, tlen + 1);
 	va_start(ap, ptr);
-	for (cpb = *ptr; cp = va_arg(ap, char *); cpb += strlen(cp))
+	for (cpb = *ptr; (cp = va_arg(ap, char *)); cpb += strlen(cp))
 		strcpy(cpb, cp);
 	va_end(ap);
 }
@@ -1003,6 +1006,7 @@ void set_TagField(ID3Tag *myTag, char *data,ID3_FrameID id)
 {       
         ID3Frame *myFrame;
         ID3Frame *pFrame;
+	char *conv_str = NULL;
         
         myFrame=ID3Frame_NewID(id);
 
@@ -1012,9 +1016,13 @@ void set_TagField(ID3Tag *myTag, char *data,ID3_FrameID id)
                 ID3Tag_RemoveFrame(myTag,pFrame);
         }
 
-        ID3Field_SetASCII(ID3Frame_GetField(myFrame,ID3FN_TEXT),data);
+	conv_str = g_locale_from_utf8(data, -1, NULL, NULL, NULL);
+
+        ID3Field_SetASCII(ID3Frame_GetField(myFrame,ID3FN_TEXT),conv_str);
         ID3Tag_AttachFrame(myTag,myFrame);
 
+	g_free(conv_str);
+
         return;
 }
 
@@ -1052,6 +1060,7 @@ unsigned char id3_find_cddb_category( char *name )
 void vorbistag(char *ogg_file, 
                 char *artist,
                 char *album,
+                char *date,
                 char *title,
                 unsigned char style,
                 unsigned char track)
@@ -1060,15 +1069,24 @@ void vorbistag(char *ogg_file,
         char temp[MAX_TITLE_LENGTH];
         gchar *tagfile;
         FILE *f;
+        char *conv_artist = NULL;
+        char *conv_album = NULL;
+        char *conv_title = NULL;
+
+        conv_artist = g_locale_from_utf8(artist, -1, NULL, NULL, NULL);
+        conv_album = g_locale_from_utf8(album, -1, NULL, NULL, NULL);
+        conv_title = g_locale_from_utf8(title, -1, NULL, NULL, NULL);
 
         tagfile = g_strdup_printf("%s.tags", ogg_file);
         
         f = fopen(tagfile, "w");
-        snprintf(temp, sizeof(temp) - 1, "ARTIST=%s\n", artist);
+        snprintf(temp, sizeof(temp) - 1, "ARTIST=%s\n", conv_artist);
         fputs(temp, f);
-        snprintf(temp, sizeof(temp) - 1, "ALBUM=%s\n", album);
+        snprintf(temp, sizeof(temp) - 1, "ALBUM=%s\n", conv_album);
         fputs(temp, f);
-        snprintf(temp, sizeof(temp) - 1, "TITLE=%s\n", title);
+        snprintf(temp, sizeof(temp) - 1, "DATE=%s\n", date);
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "TITLE=%s\n", conv_title);
         fputs(temp, f);
         snprintf(temp, sizeof(temp) - 1, "GENRE=%s\n", id3_findstyle(style));
         fputs(temp, f);
@@ -1080,5 +1098,46 @@ void vorbistag(char *ogg_file,
         system(cmd);
         unlink(tagfile);
         free(tagfile);
+
+        g_free(conv_artist);
+        g_free(conv_album);
+        g_free(conv_title);
 }
 
+// utility function to write flac tags - R. Turnbull 1-2-2010
+
+void flactag(char *flac_file, 
+                char *artist,
+                char *album,
+                char *date,
+                char *title,
+                unsigned char style,
+                unsigned char track)
+{
+        char cmd[MAX_COMMAND_LENGTH];
+        char temp[MAX_TITLE_LENGTH];
+        gchar *tagfile;
+        FILE *f;
+
+        tagfile = g_strdup_printf("%s.tags", flac_file);
+        
+        f = fopen(tagfile, "w");
+        snprintf(temp, sizeof(temp) - 1, "ARTIST=%s\n", artist);
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "ALBUM=%s\n", album);
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "DATE=%s\n", date);
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "TITLE=%s\n", title);
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "GENRE=%s\n", id3_findstyle(style));
+        fputs(temp, f);
+        snprintf(temp, sizeof(temp) - 1, "TRACKNUMBER=%d\n", track);
+        fputs(temp, f);
+        fclose(f);
+
+        snprintf(cmd, sizeof(cmd) - 1, "metaflac --import-tags-from='%s' '%s'", tagfile, flac_file);
+        system(cmd);
+        unlink(tagfile);
+        free(tagfile);
+}
